Files
alibaba--mnn/doc/API/html/functions_d.html
T
2026-07-13 13:33:03 +08:00

113 lines
4.6 KiB
HTML

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "https://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/xhtml;charset=UTF-8"/>
<meta http-equiv="X-UA-Compatible" content="IE=9"/>
<meta name="generator" content="Doxygen 1.8.15"/>
<meta name="viewport" content="width=device-width, initial-scale=1"/>
<title>MNN: 类成员</title>
<link href="tabs.css" rel="stylesheet" type="text/css"/>
<script type="text/javascript" src="jquery.js"></script>
<script type="text/javascript" src="dynsections.js"></script>
<link href="doxygen.css" rel="stylesheet" type="text/css" />
</head>
<body>
<div id="top"><!-- do not remove this div, it is closed by doxygen! -->
<div id="titlearea">
<table cellspacing="0" cellpadding="0">
<tbody>
<tr style="height: 56px;">
<td id="projectalign" style="padding-left: 0.5em;">
<div id="projectname">MNN
&#160;<span id="projectnumber">1.0</span>
</div>
</td>
</tr>
</tbody>
</table>
</div>
<!-- end header part -->
<!-- 制作者 Doxygen 1.8.15 -->
<script type="text/javascript" src="menudata.js"></script>
<script type="text/javascript" src="menu.js"></script>
<script type="text/javascript">
/* @license magnet:?xt=urn:btih:cf05388f2679ee054f2beb29a391d25f4e673ac3&amp;dn=gpl-2.0.txt GPL-v2 */
$(function() {
initMenu('',false,false,'search.php','搜索');
});
/* @license-end */</script>
<div id="main-nav"></div>
</div><!-- top -->
<div class="contents">
<div class="textblock">这里列出了所有类成员,并附带类的详细说明:</div>
<h3><a id="index_d"></a>- d -</h3><ul>
<li>DataReorderType
: <a class="el" href="class_m_n_n_1_1_tensor.html#a1fa4cb1d96822754ca18a838fdc3ad03">MNN::Tensor</a>
</li>
<li>destFormat
: <a class="el" href="struct_m_n_n_1_1_c_v_1_1_image_process_1_1_config.html#a5ae4b5b53690e53e4a5d118cc7dc7633">MNN::CV::ImageProcess::Config</a>
</li>
<li>detach_native
: <a class="el" href="structhalide__device__interface__t.html#ad22c6f186583b56c91652261e905038f">halide_device_interface_t</a>
</li>
<li>device
: <a class="el" href="structhalide__buffer__t.html#a51aa231b39c37cb777369dda8825030f">halide_buffer_t</a>
</li>
<li>device_and_host_free
: <a class="el" href="structhalide__device__interface__t.html#adfe1bff4d8a864c6450bfe10adbed304">halide_device_interface_t</a>
</li>
<li>device_and_host_malloc
: <a class="el" href="structhalide__device__interface__t.html#a0caa167abc636a7c7af4c602496e61cd">halide_device_interface_t</a>
</li>
<li>device_crop
: <a class="el" href="structhalide__device__interface__t.html#a8a091d3679d588771f88172b8a867bd2">halide_device_interface_t</a>
</li>
<li>device_free
: <a class="el" href="structhalide__device__interface__t.html#ab0bd6619c5acb90929eefa8c94488ebe">halide_device_interface_t</a>
</li>
<li>device_interface
: <a class="el" href="structhalide__buffer__t.html#ab449476b5d2b9a6eddb7bd813b7c8f6c">halide_buffer_t</a>
</li>
<li>device_malloc
: <a class="el" href="structhalide__device__interface__t.html#aefe045212c1c0cc8993ad77b4c7d793b">halide_device_interface_t</a>
</li>
<li>device_release
: <a class="el" href="structhalide__device__interface__t.html#a8d54f5cfdce5abfe5079e746ec6e9a32">halide_device_interface_t</a>
</li>
<li>device_release_crop
: <a class="el" href="structhalide__device__interface__t.html#a3a61cbd45258f14821c95f9b62d38d29">halide_device_interface_t</a>
</li>
<li>device_sync
: <a class="el" href="structhalide__device__interface__t.html#ac7e27bf4acf3d42a41bca1ca15088170">halide_device_interface_t</a>
</li>
<li>deviceId()
: <a class="el" href="class_m_n_n_1_1_tensor.html#a79200212a531a64e861f87f394077889">MNN::Tensor</a>
</li>
<li>dim
: <a class="el" href="structhalide__buffer__t.html#a36ad75ba5fff094906f338aa48722bbe">halide_buffer_t</a>
</li>
<li>dimensions
: <a class="el" href="structhalide__buffer__t.html#a15a026342a3f8402f06d8b0f9f1391dc">halide_buffer_t</a>
, <a class="el" href="class_m_n_n_1_1_tensor.html#a048c5b3e7287526a825948fc1d9bf8fb">MNN::Tensor</a>
</li>
<li>DimensionType
: <a class="el" href="class_m_n_n_1_1_tensor.html#a1a270092aad286acb9b3112a395ebd56">MNN::Tensor</a>
</li>
<li>dirtyMatrixTypeCache()
: <a class="el" href="class_m_n_n_1_1_c_v_1_1_matrix.html#af68596240a7b1dded463fd642f9a3362">MNN::CV::Matrix</a>
</li>
<li>dump()
: <a class="el" href="class_m_n_n_1_1_c_v_1_1_matrix.html#ad6c8ab196c75af4f95a87d1edc4a5e3b">MNN::CV::Matrix</a>
</li>
</ul>
</div><!-- contents -->
<!-- start footer part -->
<hr class="footer"/><address class="footer"><small>
制作者 &#160;<a href="http://www.doxygen.org/index.html">
<img class="footer" src="doxygen.png" alt="doxygen"/>
</a> 1.8.15
</small></address>
</body>
</html>